==> haskell-bencode-0.6.0.0-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-bencode/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-e5f24bcf805f718c4b43d7a9f9a5fc93
key: benco_FpEUD6qLcdW7obsCEV2VQH
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/bencode-0.6.0.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-FpEUD6qLcdW7obsCEV2VQH
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.0.0-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-bencode/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-14f919fcb31bcbb40f52f9f2fa9d87cf
key: benco_BKyucoU6UVQAAep7Q0ykiN
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/bencode-0.6.0.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-BKyucoU6UVQAAep7Q0ykiN
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
